#include "emailtextscene.h"
#include "ui_emailtextscene.h"

#include <QMessageBox>
#include <iostream>
#include <outputdialog.h>
#include <check/check.h>

EmailTextScene::EmailTextScene(QWidget *parent)
    : QWidget(parent)
    , ui(new Ui::EmailTextScene) {
    ui->setupUi(this);

    modules = parser.get_modules_names();

    for (auto &module : modules) {
        ui->store_combo_box->addItem(QString::fromStdString(module));
    }
}

EmailTextScene::~EmailTextScene() {
    delete ui;
}

void EmailTextScene::on_parse_button_clicked() {
    std::wstring checkContent = ui->check_content->toPlainText().toStdWString();
    parser.set_module(parser.search_modules()[ui->store_combo_box->currentIndex()]);

    std::vector<Goods> goods = parser.parse(checkContent);
    if (goods.size() == 0) {
        QMessageBox infoDialog;
        infoDialog.setText(tr("An error has occured. Check was matched incorrectly. Vector sizes are different. Please, contact the developer."));
        infoDialog.setIcon(QMessageBox::Critical);
        infoDialog.setWindowTitle(tr("Error in parsing"));
        infoDialog.exec();
        return;
    }

    Check check;
    check.add_goods(goods);

    OutputDialog d(this, check);
    d.show();
    d.exec();
}


void EmailTextScene::on_check_content_textChanged() {
    std::string store = parser.try_autodetect_store(ui->check_content->toPlainText().toStdString());
    if (store == "") {
        std::cerr << tr("Could not autodetect store. If you beleive that this is an error, please, report to the developer.").toStdString() << std::endl;
        return;
    }
    unsigned int index = ui->store_combo_box->findText(QString::fromStdString(store));
    ui->store_combo_box->setCurrentIndex(index);
}

